
#ifndef KTPCOMMONINTERNALS_EXPORT_H
#define KTPCOMMONINTERNALS_EXPORT_H

#ifdef KTPCOMMONINTERNALS_STATIC_DEFINE
#  define KTPCOMMONINTERNALS_EXPORT
#  define KTPCOMMONINTERNALS_NO_EXPORT
#else
#  ifndef KTPCOMMONINTERNALS_EXPORT
#    ifdef KTpCommonInternals_EXPORTS
        /* We are building this library */
#      define KTPCOMMONINTERNALS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KTPCOMMONINTERNALS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KTPCOMMONINTERNALS_NO_EXPORT
#    define KTPCOMMONINTERNALS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KTPCOMMONINTERNALS_DEPRECATED
#  define KTPCOMMONINTERNALS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KTPCOMMONINTERNALS_DEPRECATED_EXPORT
#  define KTPCOMMONINTERNALS_DEPRECATED_EXPORT KTPCOMMONINTERNALS_EXPORT KTPCOMMONINTERNALS_DEPRECATED
#endif

#ifndef KTPCOMMONINTERNALS_DEPRECATED_NO_EXPORT
#  define KTPCOMMONINTERNALS_DEPRECATED_NO_EXPORT KTPCOMMONINTERNALS_NO_EXPORT KTPCOMMONINTERNALS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KTPCOMMONINTERNALS_NO_DEPRECATED
#    define KTPCOMMONINTERNALS_NO_DEPRECATED
#  endif
#endif

#endif /* KTPCOMMONINTERNALS_EXPORT_H */
