
#ifndef KTPOTR_EXPORT_H
#define KTPOTR_EXPORT_H

#ifdef KTPOTR_STATIC_DEFINE
#  define KTPOTR_EXPORT
#  define KTPOTR_NO_EXPORT
#else
#  ifndef KTPOTR_EXPORT
#    ifdef MAKE_KTP_LIB
        /* We are building this library */
#      define KTPOTR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KTPOTR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KTPOTR_NO_EXPORT
#    define KTPOTR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KTPOTR_DEPRECATED
#  define KTPOTR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KTPOTR_DEPRECATED_EXPORT
#  define KTPOTR_DEPRECATED_EXPORT KTPOTR_EXPORT KTPOTR_DEPRECATED
#endif

#ifndef KTPOTR_DEPRECATED_NO_EXPORT
#  define KTPOTR_DEPRECATED_NO_EXPORT KTPOTR_NO_EXPORT KTPOTR_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KTPOTR_NO_DEPRECATED
#    define KTPOTR_NO_DEPRECATED
#  endif
#endif

#endif /* KTPOTR_EXPORT_H */
